@@ -35,14 +35,4 @@ NPM_VERSION_FILTER = setting_overrides.get(
 NPM_INSTALL_COMMAND = setting_overrides.get(
     'NPM_INSTALL_COMMAND',
     'install',
-)
-
-RAISE_ON_MISSING_DEPENDENCIES = setting_overrides.get(
-    'RAISE_ON_MISSING_DEPENDENCIES',
-    True,
-)
-
-RAISE_ON_OUTDATED_DEPENDENCIES = setting_overrides.get(
-    'RAISE_ON_OUTDATED_DEPENDENCIES',
-    True,
 )
\ No newline at end of file
